Skýrslur | OiRA

Þemu

# Skýrslur

Þú getur notað skýrslu til að:

- senda skrásett gögn til eftirlitsaðila;
- veita upplýsingar til hlutaðeigenda (starfsmanna, öryggisfulltrúa, atvinnurekenda, vinnuverndarsérfræðinga, o.s.frv.);
- fylgjast með og leggja mat á hvort gripið hafi verið til nauðsynlegra aðgerða;
- skrásetja endurskoðun á mati við breyttar kringumstæður (nýjar vélar/starfsmenn, eða í samræmi við niðurstöður rannsókna á slysum, o.s.frv.).

Þú getur vistað skýrsluna á tölvuna þína og prentað hana út. Þú getur einnig breytt henni eða bætt við frekari upplýsingum. Hafðu í huga að allar breytingar á skýrslu, sem þú hefur hlaðið niður, verða EKKI vistaðar í OiRA-verkfærinu.

## Val á skýrslum

Mismunandi skýrslur eru í boði í mismunandi tilgangi. Skýrslur í boði í viðkomandi verkfæri fara eftir ákvörðunum OiRA landsskrifstofunnar/hugbúnaðarhönnuðarins.

Skýrslur í boði.

### Heildarskýrsla

Snið: Word / Office Open XML (.docx). Þú getur breytt henni eftir að þú hefur hlaðið henni niður.

Inniheldur: allar upplýsingar og athugasemdir sem þú hefur skráð í áhættumatsferlinu.

Notaðu hana til að: veita eftirlitsaðilum upplýsingar um áhættumatið (t.d. vinnueftirlitinu).

### Aðgerðaráætlun

Snið: Excel / Office Open XML (.xlsx). Þú getur breytt henni eftir að þú hefur hlaðið henni niður

Inniheldur: upplýsingar um allar þær ráðstafanir sem þú hefur valið að hrinda í framkvæmd.

Notaðu hana til að:

- fylgja með virkum hætti á eftir framkvæmd þeirra ráðstafana sem þú hefur valið;
- stjórna vandamálum/áhættu á vinnustaðnum þínum (tiltekin verkefni, sérfræðiþekking, ábyrgðarsvið, tímafrestir).

### Yfirlit yfir áhættu

Snið: Portable Document Format (.pdf). Þú getur ekki breytt því eftir að þú hefur hlaðið því niður.

Inniheldur: yfirlit yfir greinda áhættu

Notaðu það til að:

- fá yfirlit yfir stöðu áhættu á vinnustaðnum þínum;
- veita hlutaðeigendum upplýsingar;
- fylgjast með hvort tekið sé á áhættu/ráðstöfunum með viðeigandi hætti.

### Yfirlit yfir ráðstafanir

Snið: Portable Document Format (.pdf). Þú getur ekki breytt því eftir að þú hefur hlaðið því niður.

Inniheldur: yfirlit yfir ráðstafanir sem á að hrinda í framkvæmd.

Notaðu það til að:

- fá yfirlit yfir stöðu ráðstafana sem þú hefur ákveðið að hrinda í framkvæmd;
- veita hlutaðeigendum upplýsingar;
- fylgjast með hvort tekið sé á áhættu/ráðstöfunum með viðeigandi hætti.

Scroll to top Load toolbar…
Back

## 4-reports.md

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More